@@ -26,6 +26,8 @@
 
 #include <QColor>
 #include <QDir>
+#include <QFile>
+#include <QFileDialog>
 #include <QString>
 
 #include "dialog.h"
@@ -84,6 +86,7 @@ Dialog::Dialog(QWidget *parent) :
     connect(ui->colorRSpinBox, SIGNAL(valueChanged(int)), ui->colorChooserButton, SLOT(updateR(int)));
     connect(ui->colorGSpinBox, SIGNAL(valueChanged(int)), ui->colorChooserButton, SLOT(updateG(int)));
     connect(ui->colorBSpinBox, SIGNAL(valueChanged(int)), ui->colorChooserButton, SLOT(updateB(int)));
+    connect(ui->alarmIndicatorIconPushButton, SIGNAL(pressed()), this, SLOT(fileDialog()));
 
 #ifdef Q_WS_MAEMO_5
     /*
@@ -105,6 +108,7 @@ Dialog::Dialog(QWidget *parent) :
     offset = new GConfItem(GCONF_PATH_CLOCK + "/offset");
     timeZone = new GConfItem(GCONF_PATH_CLOCK + "/time_zone");
     customFormat = new GConfItem(GCONF_PATH_CLOCK + "/custom_format");
+    alarmIndicatorIcon = new GConfItem(GCONF_PATH_CLOCK + "/alarm_indicator_icon");
 
     /*
      * Initialize UI with the values stored in gconf.
@@ -126,6 +130,13 @@ Dialog::Dialog(QWidget *parent) :
     ui->padZerosCheckBox->setChecked(padZeros->value().toBool());
     ui->customFormatLineEdit->setText(customFormat->value().toString());
 
+    QString alarmIconName = alarmIndicatorIcon->value().toString();
+    if(alarmIconName != NULL
+       && alarmIconName.compare(tr("Select File")) != 0
+       && QFile::exists(alarmIconName)){
+        ui->alarmIndicatorIconLineEdit->setText(alarmIconName);
+    }
+
     /*
      * Get time zones and initialize combo box.
      */
@@ -204,6 +215,15 @@ void Dialog::accept(){
 
     customFormat->set(ui->customFormatLineEdit->text());
 
+    QString alarmIconName = ui->alarmIndicatorIconLineEdit->text();
+    if(alarmIconName != NULL
+       && alarmIconName.compare(tr("Select File")) != 0
+       && QFile::exists(alarmIconName)){
+        alarmIndicatorIcon->set(alarmIconName);
+    }else{
+        alarmIndicatorIcon->set("");
+    }
+
     /*
      * Hack to get things updated even when the clock is not changed.
      * This is currently needed as the settings are currently updated
@@ -217,6 +237,35 @@ void Dialog::accept(){
     done(1);
 }
 
+void Dialog::fileDialog(){
+    qDebug("Entering RecordDialog::fileDialog()...");
+
+    QString selectedFile = ui->alarmIndicatorIconLineEdit->text();
+    if(selectedFile == NULL
+       || selectedFile.compare(tr("Select File")) == 0
+       || (! QFile::exists(selectedFile)) ){
+        selectedFile = QDir::home().absolutePath() + "/MyDocs";
+    }
+
+    QString newFile = QFileDialog::getOpenFileName(
+            this,
+            tr("Select Icon."),
+            selectedFile,
+            tr("PNG Files (*.png)"));
+
+    if(newFile != NULL){
+        fileSelected(newFile);
+    }
+}
+
+void Dialog::fileSelected(QString fileName){
+    if(fileName != NULL
+       && fileName.compare(tr("Select File")) != 0
+       && QFile::exists(fileName)){
+        ui->alarmIndicatorIconLineEdit->setText(fileName);
+    }
+}
+
 void Dialog::updateColor(QColor color){
     int r;
     int g;
