@@ -52,6 +52,7 @@ public slots:
 
 private:
     Ui::Dialog *ui;
+    void fileSelected(QString fileName);
 
 #ifdef Q_WS_MAEMO_5
     GConfItem *clockName;
@@ -72,12 +73,16 @@ private:
     GConfItem *timeZone;
 
     GConfItem *customFormat;
+    GConfItem *alarmIndicatorIcon;
 
     QStringList cityNames;
     QStringList countryNames;
     QStringList timeZones;
 #endif
 
+private slots:
+    void fileDialog();
+
 };
 
 #endif // DIALOG_H
