@@ -79,6 +79,12 @@ class Clock():
         self.context.restore()
 
     def draw_alarm_indicator(self):
+        # Hack to correctly load icon after a restart.
+        # Guess is that MyDocs is mounted after the status menu is started.
+        # Consequently, the icon is not found and thus not loaded properly even if set correctly.
+        if self.alarm_indicator_icon is None and self.alarm_indicator_icon_file != "" and os.path.isfile(self.alarm_indicator_icon_file) :
+            self.alarm_indicator_icon = cairo.ImageSurface.create_from_png(self.alarm_indicator_icon_file)
+
         if self.alarm_indicator_icon is not None :
             self.context.set_source_surface(self.alarm_indicator_icon, self.drawing_area.get_size_request()[0] - self.alarm_indicator_icon.get_width(), 0)
             self.context.paint()
@@ -178,11 +184,11 @@ class Clock():
         self.custom_format = self.gconf_client.get_string(GCONF_DIR + "/custom_format")
 
         self.alarm_indicator_icon = None
-        alarm_indicator_icon_file = self.gconf_client.get_string(GCONF_DIR + "/alarm_indicator_icon")
-        if os.path.isfile(alarm_indicator_icon_file) :
-            self.alarm_indicator_icon = cairo.ImageSurface.create_from_png(alarm_indicator_icon_file)
+        self.alarm_indicator_icon_file = self.gconf_client.get_string(GCONF_DIR + "/alarm_indicator_icon")
+        if os.path.isfile(self.alarm_indicator_icon_file) :
+            self.alarm_indicator_icon = cairo.ImageSurface.create_from_png(self.alarm_indicator_icon_file)
         else:
-            print "Image file does not exist: " + alarm_indicator_icon_file
+            print "Image file does not exist: " + self.alarm_indicator_icon_file
 
 # Currently we do not use the callback (see above).
 #        self.gconf_client.notify_add(GCONF_DIR, self.gconf_cb)
